#!/usr/bin/env python
""" Show the details for a given chaos expansion, based on its concise
dictionary representation.

"""
import os, pickle, sys
from textwrap import dedent

import logging
logging.basicConfig(level=logging.INFO, format="%(message)s")
logger = logging.getLogger()

from argparse import ArgumentParser, RawDescriptionHelpFormatter

parser = ArgumentParser(description=__doc__,
                        formatter_class=RawDescriptionHelpFormatter)
parser.add_argument("exp_name", type=str, help="name of PCM experiment to reference")

def show_exp(exp_dict, results_dict):

    # Experiment name
    exp_name = exp_dict['exp_name']
    logger.info("\n" + exp_name)

    ## Variable table
    variables = exp_dict['variables']
    logger.info("\n" + "Expansion Variables")
    logger.info("-------------------")
    for v in variables:
        long_name, short_name, ix, dist_list, offset, _ = v
        dist, a, b = dist_list
        logger.info("{:>10s} {:>8s}({:3.1f}, {:3.1f})".format(
                    long_name, dist, a, b))

    ## Response fcns
    logger.info("\nResponses")
    logger.info("---------")
    for r in exp_dict['responses']:
        logger.info("{:>10s}".format(r))

    ## Result locs
    param_name = exp_dict['param_name']
    param_vals = exp_dict['param_vals']
    logger.info("\nResult Locations")
    logger.info("----------------")
    for v in param_vals:
        full_param = "{}_{}".format(param_name, v)
        path_to_results = results_dict[full_param]
        logger.info("{:>20s} {}".format(
                    full_param,
                    os.path.join(os.getcwd(), 'save', path_to_results)))


if __name__ == "__main__":

    args = parser.parse_args()

    ## Load in the experiment dictionary, which contains information on
    ## the parameter space structure and contents
    exp_dict = pickle.load(open("%s_exp.dict" % args.exp_name, 'r'))
    results_dict = pickle.load(open("%s_results.dict" % args.exp_name, 'r'))
    show_exp(exp_dict, results_dict)

    # Look up the path to the saved model_run.py so that it can be
    # import later to run the correct model configuration.
    path_to_model_run = os.path.join('save',
                                     results_dict[results_dict.keys()[0]])

    directive_base = exp_dict['directive_base']
    variables = exp_dict['variables']
    responses = exp_dict['responses']
    dists = [v[3][0] for v in variables]
    offsets = [v[4] for v in variables]
